
import os
import shlex
import random
import subprocess

import click


COMMIT_EMOJIS = [
    ':closed_book:',
    ':green_book:',
    ':blue_book:',
    ':orange_book:',
    ':notebook:',
    ':notebook_with_decorative_cover:',
    ':ledger:',
    ':books:',
    ':pencil2:',
    ':black_nib:',
    ':book:',
    ':memo:',
    ':pencil:',
]


def choose_commit_emoji():
    return random.choice(COMMIT_EMOJIS)


def run(command, env=None, bg=False):
    click.secho(command, fg='magenta', bold=True, err=True)

    options = {
        'env': dict(os.environ, **env) if env else os.environ,
        # 'stdout': subprocess.PIPE,
        'stderr': subprocess.STDOUT,
        'universal_newlines': True,
    }
    if bg:
        return subprocess.Popen(shlex.split(command), **options)

    options['check'] = True
    proc = subprocess.run(shlex.split(command), **options)
    return proc.stdout


def header(text):
    click.secho(text, fg='yellow')


def abort(context):
    click.echo('Aborted!')
    context.exit(1)




import os
import time

import click

from . import blog
from .helpers import run, abort


PORT = 8000


@blog.command()
@click.pass_context
def preview(context):
    """Opens local preview of your blog website"""

    config = context.obj

    server_proc = None
    os.chdir(config['OUTPUT_DIR'])

    pelican(config, '--verbose', '--ignore-cache')
    try:
        try:
            command = 'python -m http.server ' + str(PORT)
            server_proc = run(command, bg=True)

            time.sleep(3)
            click.launch('http://localhost:8000')

            pelican(config, '--autoreload')
        except:
            if server_proc is not None:
                server_proc.kill()
            raise
    except KeyboardInterrupt:
        abort(context)


def pelican(config, *extra_params):
    command = 'pelican "{content}" --output="{output}" --settings="{settings}"'
    if extra_params:
        command = ' '.join([command] + list(extra_params))

    run(command.format(
        content=config['CONTENT_DIR'],
        output=config['OUTPUT_DIR'],
        settings=os.path.join(config['CWD'], config['SETTINGS_PATH']),
    ))
